# I/O

Read and write to files on disk and databases like PostGIS.

::: geoarrow.rust.core
    options:
      filters:
        - "!^_"
      members:
        - read_csv
        - read_flatgeobuf
        - read_flatgeobuf_async
        - read_geojson
        - read_geojson_lines
        - read_ipc
        - read_ipc_stream
        - read_parquet
        - read_parquet_async
        - read_postgis
        - read_postgis_async
        - read_pyogrio
        - write_csv
        - write_flatgeobuf
        - write_geojson
        - write_geojson_lines
        - write_ipc
        - write_ipc_stream
        - write_parquet
        - ObjectStore
        - ParquetDataset
        - ParquetFile
